![Dicognito logo](https://github.com/blairconrad/dicognito/raw/master/assets/dicognito_128.png "Dicognito logo")

Dicognito anonymizes DICOM files.

----
Logo: Remixed from [Radiology](https://thenounproject.com/search/?q=x-ray&i=1777366)
by [priyanka](https://thenounproject.com/creativepriyanka/) and [Incognito](https://thenounproject.com/search/?q=incognito&i=7572) by [d͡ʒɛrmi Good](https://thenounproject.com/geremygood/) from [the Noun Project](https://thenounproject.com/).
